# metamodel_version: 1.7.0
type Annotation
  {
    labelset: String!
    cellLabel: String!
    cellFullname: String
    cellOntologyTermId: CellTypeEnum
    cellOntologyTerm: String
    cellIds: [String]
    rationale: String
    rationaleDois: [String]
    markerGeneEvidence: [String]
    synonyms: [String]
    reviews: [Review]
    authorAnnotationFields: Any
  }

type Any
  {
  }

type AutomatedAnnotation
  {
    algorithmName: String!
    algorithmVersion: String!
    algorithmRepoUrl: String!
    referenceLocation: String
  }

type Labelset
  {
    name: String!
    description: String
    annotationMethod: AnnotationMethodOptions
    automatedAnnotation: AutomatedAnnotation
  }

type Review
  {
    datestamp: String!
    reviewer: String
    review: ReviewOptions
    explanation: String
  }

type Taxonomy
  {
    matrixFileId: String
    title: String!
    description: String
    cellannotationSchemaVersion: String
    cellannotationTimestamp: String
    cellannotationVersion: String
    cellannotationUrl: String
    authorList: String
    authorName: String!
    authorContact: String
    orcid: String
    labelsets: [Labelset]!
    annotations: [Annotation]!
  }

